pub struct GateLevel { /* private fields */ }Expand description
The level of a gate in a circuit. All gates with the same level can be executed in parallel as they do not depend on each other.
The gate level is a pair of integers: the first one is the communication round (level), and the second one is a relative level within the same communication round. The gate communication round is the number of communications rounds which have passed after the gate execution.
Implementations