#[repr(C)]pub enum Gate<C: Curve> {
Show 29 variants
Input(Input),
Constant(Constant<C>),
Random {
algebraic_type: AlgebraicType,
batch_size: BatchSize,
},
FieldShareUnaryOp {
x: GateIndex,
op: FieldShareUnaryOp,
},
FieldShareBinaryOp {
x: GateIndex,
y: GateIndex,
op: FieldShareBinaryOp,
},
BatchSummation {
x: GateIndex,
},
BitShareUnaryOp {
x: GateIndex,
op: BitShareUnaryOp,
},
BitShareBinaryOp {
x: GateIndex,
y: GateIndex,
op: BitShareBinaryOp,
},
PointShareUnaryOp {
p: GateIndex,
op: PointShareUnaryOp,
},
PointShareBinaryOp {
p: GateIndex,
y: GateIndex,
op: PointShareBinaryOp,
},
FieldPlaintextUnaryOp {
x: GateIndex,
op: FieldPlaintextUnaryOp,
},
FieldPlaintextBinaryOp {
x: GateIndex,
y: GateIndex,
op: FieldPlaintextBinaryOp,
},
BitPlaintextUnaryOp {
x: GateIndex,
op: BitPlaintextUnaryOp,
},
BitPlaintextBinaryOp {
x: GateIndex,
y: GateIndex,
op: BitPlaintextBinaryOp,
},
PointPlaintextUnaryOp {
p: GateIndex,
op: PointPlaintextUnaryOp,
},
PointPlaintextBinaryOp {
p: GateIndex,
y: GateIndex,
op: PointPlaintextBinaryOp,
},
DaBit {
field_type: FieldType,
batch_size: BatchSize,
},
GetDaBitFieldShare {
x: GateIndex,
},
GetDaBitSharedBit {
x: GateIndex,
},
BaseFieldPow {
x: GateIndex,
exp: BoxedUint,
},
BitPlaintextToField {
x: GateIndex,
field_type: FieldType,
},
FieldPlaintextToBit {
x: GateIndex,
},
ExtractFromBatch {
x: GateIndex,
slice: Slice,
},
CollectToBatch {
wires: Vec<GateIndex>,
},
PointFromPlaintextExtendedEdwards {
wires: Vec<GateIndex>,
},
PlaintextPointToExtendedEdwards {
point: GateIndex,
},
PlaintextKeccakF1600 {
x: GateIndex,
},
CompressPlaintextPoint {
point: GateIndex,
},
KeyRecoveryPlaintextComputeErrors {
d_minus_one: GateIndex,
syndromes: GateIndex,
},
}Expand description
Gate operations, where the operation arguments correspond to wire label.
Variants
Input(Input)
Input a wire
Constant(Constant<C>)
Input a constant value
Random
Generate random shares
Field share unary operations
Field share binary operations, where the second wire may be a plaintext.
BatchSummation
Operations with elliptic curve points
FieldPlaintextUnaryOp
Field plaintext unary operations
FieldPlaintextBinaryOp
Field plaintext binary operations
BitPlaintextUnaryOp
BitPlaintextBinaryOp
PointPlaintextUnaryOp
PointPlaintextBinaryOp
DaBit
Request a daBit
BaseFieldPow
Base field exponentiation operation
BitPlaintextToField
Bit plaintext conversion operations
FieldPlaintextToBit
ExtractFromBatch
Get a slice of elements from a batched wire
CollectToBatch
PointFromPlaintextExtendedEdwards
PlaintextPointToExtendedEdwards
PlaintextKeccakF1600
CompressPlaintextPoint
KeyRecoveryPlaintextComputeErrors
Implementations
Sourceimpl<C: Curve> Gate<C>
impl<C: Curve> Gate<C>
Sourcepub fn get_inputs(&self) -> Vec<GateIndex> ⓘ
pub fn get_inputs(&self) -> Vec<GateIndex> ⓘ
Returns the indices of gate inputs.
Sourcepub fn map_inputs<F: FnMut(GateIndex) -> GateIndex>(self, f: F) -> Self
pub fn map_inputs<F: FnMut(GateIndex) -> GateIndex>(self, f: F) -> Self
Maps inplace gate inputs using the given function.
Sourcepub fn try_replace_inputs(
self,
inputs: Vec<GateIndex>,
) -> Result<Self, CircuitError<C>>
pub fn try_replace_inputs( self, inputs: Vec<GateIndex>, ) -> Result<Self, CircuitError<C>>
Tries to replace the gate inputs with the given ones.
This function returns an error if the number of given inputs does not match the number of gate inputs.