BatchSize

Trait BatchSize 

pub trait BatchSize:
    Positive
    + Add<B1, Output: Positive + Add<B1, Output: Positive>>
    + Mul<U2, Output: Positive + Mul<U3, Output = Prod<Self, U6>>>
    + Mul<U3, Output: Positive + Mul<U2, Output = Prod<Self, U6>>>
    + Mul<U4, Output: Positive>
    + Mul<U5, Output: Positive>
    + Mul<U6, Output: Positive + Add<B1, Output: Positive>> { }
A generic trait to serve as batch size across all protocols. To be replaced by const generics if they ever stabilize.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Positive + Add<B1, Output: PositivePlusOne> + Mul<U2, Output: Positive + Mul<U3, Output = Prod<T, U6>>> + Mul<U3, Output: Positive + Mul<U2, Output = Prod<T, U6>>> + Mul<U4, Output: Positive> + Mul<U5, Output: Positive> + Mul<U6, Output: PositivePlusOne>> BatchSize for T