Module bundler
core_
utils
0.8.6
Module bundler
Module Items
Structs
Traits
In core_
utils::
preprocessing
core_utils
::
preprocessing
Module
bundler
Structs

Stream
Bundler
Stream bundler, holding one stream per preprocessing type, to provide all preprocessing for a circuit via its streams.
Traits

Bundled
Stream
A stream that can fill a
StreamBundler
slot.