pub struct StreamBundler<C: MpcConfig> {
pub basefield_dabit_stream: Box<dyn BundledStream<DaBit<BaseFieldOf<C>>>>,
pub basefield_singlet_stream: Box<dyn BundledStream<Singlet<BaseFieldOf<C>>>>,
pub basefield_triple_stream: Box<dyn BundledStream<Triple<BaseFieldOf<C>>>>,
pub binary_singlet_stream: Box<dyn BundledStream<Singlet<Gf2_128>>>,
pub binary_triple_stream: Box<dyn BundledStream<Triple<Gf2_128>>>,
pub mpc_field_dabit_stream: Box<dyn BundledStream<DaBit<MpcFieldOf<C>>>>,
pub mpc_field_singlet_stream: Box<dyn BundledStream<Singlet<MpcFieldOf<C>>>>,
pub mpc_field_triple_stream: Box<dyn BundledStream<Triple<MpcFieldOf<C>>>>,
pub scalar_dabit_stream: Box<dyn BundledStream<DaBit<ScalarFieldOf<C>>>>,
pub scalar_singlet_stream: Box<dyn BundledStream<Singlet<ScalarFieldOf<C>>>>,
pub scalar_triple_stream: Box<dyn BundledStream<Triple<ScalarFieldOf<C>>>>,
}Expand description
Stream bundler, holding one stream per preprocessing type, to provide all preprocessing for a circuit via its streams.
Fields
basefield_dabit_stream: Box<dyn BundledStream<DaBit<BaseFieldOf<C>>>>basefield_singlet_stream: Box<dyn BundledStream<Singlet<BaseFieldOf<C>>>>basefield_triple_stream: Box<dyn BundledStream<Triple<BaseFieldOf<C>>>>binary_singlet_stream: Box<dyn BundledStream<Singlet<Gf2_128>>>binary_triple_stream: Box<dyn BundledStream<Triple<Gf2_128>>>mpc_field_dabit_stream: Box<dyn BundledStream<DaBit<MpcFieldOf<C>>>>mpc_field_singlet_stream: Box<dyn BundledStream<Singlet<MpcFieldOf<C>>>>mpc_field_triple_stream: Box<dyn BundledStream<Triple<MpcFieldOf<C>>>>scalar_dabit_stream: Box<dyn BundledStream<DaBit<ScalarFieldOf<C>>>>scalar_singlet_stream: Box<dyn BundledStream<Singlet<ScalarFieldOf<C>>>>scalar_triple_stream: Box<dyn BundledStream<Triple<ScalarFieldOf<C>>>>Implementations
Sourceimpl<C: MpcConfig> StreamBundler<C>
impl<C: MpcConfig> StreamBundler<C>
Sourcepub fn new(
basefield_dabit_stream: impl BundledStream<DaBit<BaseFieldOf<C>>> + 'static,
basefield_singlet_stream: impl BundledStream<Singlet<BaseFieldOf<C>>> + 'static,
basefield_triple_stream: impl BundledStream<Triple<BaseFieldOf<C>>> + 'static,
binary_singlet_stream: impl BundledStream<Singlet<Gf2_128>> + 'static,
binary_triple_stream: impl BundledStream<Triple<Gf2_128>> + 'static,
mpc_field_dabit_stream: impl BundledStream<DaBit<MpcFieldOf<C>>> + 'static,
mpc_field_singlet_stream: impl BundledStream<Singlet<MpcFieldOf<C>>> + 'static,
mpc_field_triple_stream: impl BundledStream<Triple<MpcFieldOf<C>>> + 'static,
scalar_dabit_stream: impl BundledStream<DaBit<ScalarFieldOf<C>>> + 'static,
scalar_singlet_stream: impl BundledStream<Singlet<ScalarFieldOf<C>>> + 'static,
scalar_triple_stream: impl BundledStream<Triple<ScalarFieldOf<C>>> + 'static,
) -> Self
pub fn new( basefield_dabit_stream: impl BundledStream<DaBit<BaseFieldOf<C>>> + 'static, basefield_singlet_stream: impl BundledStream<Singlet<BaseFieldOf<C>>> + 'static, basefield_triple_stream: impl BundledStream<Triple<BaseFieldOf<C>>> + 'static, binary_singlet_stream: impl BundledStream<Singlet<Gf2_128>> + 'static, binary_triple_stream: impl BundledStream<Triple<Gf2_128>> + 'static, mpc_field_dabit_stream: impl BundledStream<DaBit<MpcFieldOf<C>>> + 'static, mpc_field_singlet_stream: impl BundledStream<Singlet<MpcFieldOf<C>>> + 'static, mpc_field_triple_stream: impl BundledStream<Triple<MpcFieldOf<C>>> + 'static, scalar_dabit_stream: impl BundledStream<DaBit<ScalarFieldOf<C>>> + 'static, scalar_singlet_stream: impl BundledStream<Singlet<ScalarFieldOf<C>>> + 'static, scalar_triple_stream: impl BundledStream<Triple<ScalarFieldOf<C>>> + 'static, ) -> Self
Creates a new bundler from the given streams.
Sourcepub fn positions(&self) -> CircuitPreprocessing
pub fn positions(&self) -> CircuitPreprocessing
Elements delivered by every stream, per type.
Sourcepub fn buffered(&self) -> CircuitPreprocessing
pub fn buffered(&self) -> CircuitPreprocessing
Elements currently buffered in every stream, per type.
Sourcepub async fn resync(
&self,
targets: &CircuitPreprocessing,
) -> Result<(), AbortError>
pub async fn resync( &self, targets: &CircuitPreprocessing, ) -> Result<(), AbortError>
Advances every stream to its per-type target. Rejects the whole call if any target is
behind its stream’s position; otherwise dispatches all resyncs and joins them.
Sourcepub fn buffer_configs(&self) -> PerStream<SharedBufferConfig>
pub fn buffer_configs(&self) -> PerStream<SharedBufferConfig>
The shared buffer config of every stream; itself a Buffer over the whole bundle.