Module source

Module source 

A helper trait abstracting over sources of different preprocessing data. Types that implement it should be able to provide objects that resolve to either a triple or a singlet as requested, and in the order they are requested. This allows us to start online phases and generate preprocessing data on the fly instead of needing it all upfront.

Traits

DaBitSource
Retrieves DaBits for the local peer upon request.
PowPairSource
Retrieves PowPairs for the local peer upon request.
PreprocessingSource
Retrieves preprocessing elements for the local peer upon request.
SingletSource
Retrieves singlets for the local peer upon request.
TripleSource
Retrieves triples for the local peer upon request.