Module preprocessing

Module preprocessing 

Modules

errors
iterator

Traits

Preprocessing
A marker trait for preprocessing types that can be served in the online phase, maybe requiring some associated data to be generated/requested/verified. Includes verification and random generation capabilities.
PreprocessingBundler
Bundles all preprocessing sources for an MPC protocol session.