Module bundler

Module bundler 

Structs

StreamBundler
Stream bundler, holding one stream per preprocessing type, to provide all preprocessing for a circuit via its streams.

Traits

BundledStream
A stream that can fill a StreamBundler slot.