pub trait Preprocessing:
Debug
+ Sized
+ Send
+ Sync
+ Clone
+ PartialEq
+ Serialize
+ DeserializeOwned
+ SchemaWrite<Src = Self>
+ for<'a> SchemaRead<'a>
+ Reconstructible
+ VerifiableWith<VerificationData = Self::AssociatedData> {
type AssociatedData: Send + Sync + Clone + PartialEq + Serialize + DeserializeOwned + SchemaWrite<Src = Self::AssociatedData> + for<'a> SchemaRead<'a, Dst = Self::AssociatedData>;
}Expand description
A marker trait for preprocessing types that can be served in the online phase, maybe requiring some associated data to be generated/requested/verified. Includes verification and random generation capabilities.
Required Associated Types
Sourcetype AssociatedData: Send + Sync + Clone + PartialEq + Serialize + DeserializeOwned + SchemaWrite<Src = Self::AssociatedData> + for<'a> SchemaRead<'a, Dst = Self::AssociatedData>
type AssociatedData: Send + Sync + Clone + PartialEq + Serialize + DeserializeOwned + SchemaWrite<Src = Self::AssociatedData> + for<'a> SchemaRead<'a, Dst = Self::AssociatedData>
The associated data that is used to generate/request/verify this preprocessing type. E.g.,
an exponent for PowPair. Can be empty if no additional data is needed.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.